Image registration (:mod:`imaxt_image.registration`)
====================================================

.. currentmodule:: imaxt_image.registration

.. automodule:: imaxt_image.registration


Mutual Information (:mod:`imaxt_image.registration.mutual_information`)
-----------------------------------------------------------------------

.. automodule:: imaxt_image.registration.mutual_information
   :members:

Cross Correlation (:mod:`imaxt_image.registration.cross_correlation`)
---------------------------------------------------------------------

.. automodule:: imaxt_image.registration.cross_correlation
   :members:

Minimization (:mod:`imaxt_image.registration.minimization`)
-----------------------------------------------------------

.. automodule:: imaxt_image.registration.minimization
   :members:

Utils (:mod:`imaxt_image.registration.utils`)
---------------------------------------------

.. automodule:: imaxt_image.registration.utils
   :members:

